@@ -8,6 +8,8 @@
  * file that was distributed with this source code.
  */
 
+use SebastianBergmann\Exporter\Exporter;
+
 /**
  * Stubs a method by raising a user-defined exception.
  *
@@ -17,8 +19,15 @@ class PHPUnit_Framework_MockObject_Stub_Exception implements PHPUnit_Framework_M
 {
     protected $exception;
 
-    public function __construct(Exception $exception)
+    public function __construct($exception)
     {
+        // TODO Replace check with type declaration when support for PHP 5 is dropped
+        if (!$exception instanceof Throwable && !$exception instanceof Exception) {
+            throw new PHPUnit_Framework_Exception(
+                'Exception must be an instance of Throwable (PHP 7) or Exception (PHP 5)'
+            );
+        }
+
         $this->exception = $exception;
     }
 
@@ -29,9 +38,11 @@ class PHPUnit_Framework_MockObject_Stub_Exception implements PHPUnit_Framework_M
 
     public function toString()
     {
+        $exporter = new Exporter;
+
         return sprintf(
             'raise user-specified exception %s',
-            PHPUnit_Util_Type::export($this->exception)
+            $exporter->export($this->exception)
         );
     }
 }
